/**
 * JPaaS
 * Copyright 2012 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * --------------------------------------------------------------------------
 * $Id: $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.jpaas.thresholddetector.core;

import org.osgi.framework.BundleContext;
import org.ow2.jasmine.rules.osgi.impl.RulesActivator;
import org.ow2.jonas.jpaas.thresholddetector.core.actuator.Actuator;
import org.ow2.jonas.jpaas.thresholddetector.core.drools.IDroolsWorkingMemoryPoolProxy;
import org.ow2.jonas.jpaas.thresholddetector.core.drools.ThresholdDetectorWorkingMemory;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Activator of the bundle
 *
 * @author pelletib
 */
public class Activator extends RulesActivator {


    /**
     * Logger
     */
    private static Log logger = LogFactory.getLog(Activator.class);

    /* (non-Javadoc)
     * @see org.ow2.jasmine.rules.osgi.impl.RulesActivator#doStart(org.osgi.framework.BundleContext)
     */
    @Override
    protected void doStart(BundleContext bundleContext) throws Exception {

        logger.info("Starting Threshold Detector Manager");

        workingMemoryName = ThresholdDetectorWorkingMemory.WORKING_MEMORY_NAME;

        IDroolsWorkingMemoryPoolProxy iDroolsWorkingMemoryPoolProxy = new IDroolsWorkingMemoryPoolProxy(bundleContext);
        iDroolsWorkingMemoryPoolProxy.start();
        ThresholdDetector.getThresholdDetector().getWm().setWorkingMemoryPoolProxy(iDroolsWorkingMemoryPoolProxy);

        // init actuator
        Actuator actuator = new Actuator();
        actuator.init(bundleContext);
        setGlobal("actuator", actuator);
        ThresholdDetector.getThresholdDetector().setActuator(actuator);

        // provides access to jk service in the rules
        //JkManagerServiceProxy jkServiceManagerProxy = new JkManagerServiceProxy(bundleContext);
        //jkServiceManagerProxy.start();
        //rm.setJkManagerServiceProxy(jkServiceManagerProxy);

        logger.info("Threshold Detector started");
    }

    /* (non-Javadoc)
     * @see org.ow2.jasmine.rules.osgi.impl.RulesActivator#doStop(org.osgi.framework.BundleContext)
     */
    @Override
    protected void doStop(BundleContext arg0) throws Exception {
        logger.info("Threshold Detector stopped");

    }

}
