/**
 * JPaaS
 * Copyright 2012 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * --------------------------------------------------------------------------
 * $Id: $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.jpaas.thresholddetector.core.configuration;

/**
 * Configuration of the Threshold Detector Manager
 *
 * @author pelletib
 */
public class GlobalConfiguration {

    /**
     * the size of the cluster
     */
    private int clusterSize;

    /**
     * the threshold for scaling up of the cluster
     */
    private Double thresholdScaleUp;

    /**
     * the threshold for scaling down of the cluster
     */
    private Double thresholdScaleDown;

    /**
     * pattern for identifying rate probe
     */
    private String rateProbePattern;

	/**
     * pattern for identifying heartbeat probe
     */
    private String heartbeatProbePattern;


    /**
     * Notification domain
     */
    private String notificationDomain;

	/**
     * Notification server
     */
    private String notificationServer;

    /**
     * Notification to be sent by mail
     */
    private boolean notificationMailToSend;

    /**
     * Notification mail sender
     */
    private String notificationMailSender;

    /**
     * Notification mail receiver
     */
    private String notificationMailReceiver;

	/**
     * default constructor
     */
    public GlobalConfiguration() {
    }

    /**
     * @return the clusterSize
     */
    public int getClusterSize() {
        return clusterSize;
    }

    /**
     * @param clusterSize
     *            the real clusterSize to set
     */
    public void setClusterSize(int clusterSize) throws ConfigurationException {
        this.clusterSize = clusterSize;
    }

	/**
	 *
	 * @return Threshold for scaling down
	 */
    public Double getThresholdScaleDown() {
		return thresholdScaleDown;
	}


    /**
     * Set Threshold for scaling down
     * @param thresholdScaleDown
     */
	public void setThresholdScaleDown(Double thresholdScaleDown) {
		this.thresholdScaleDown = thresholdScaleDown;
	}

	/**
	 *
	 * @return Threshold for scaling up
	 */
    public Double getThresholdScaleUp() {
		return thresholdScaleUp;
	}

    /**
     * Set Threshold for scaling up
     * @param thresholdScaleUp
     */
	public void setThresholdScaleUp(Double thresholdScaleUp) {
		this.thresholdScaleUp = thresholdScaleUp;
	}

    public String getRateProbePattern() {
		return rateProbePattern;
	}

	public void setRateProbePattern(String rateProbePattern) {
		this.rateProbePattern = rateProbePattern;
	}

	public String getHeartbeatProbePattern() {
		return heartbeatProbePattern;
	}

	public void setHeartbeatProbePattern(String heartbeatProbePattern) {
		this.heartbeatProbePattern = heartbeatProbePattern;
	}

    public String getNotificationDomain() {
		return notificationDomain;
	}

	public void setNotificationDomain(String notificationDomain) {
		this.notificationDomain = notificationDomain;
	}

	public String getNotificationServer() {
		return notificationServer;
	}

	public void setNotificationServer(String notificationServer) {
		this.notificationServer = notificationServer;
	}

	public boolean isNotificationMailToSend() {
		return notificationMailToSend;
	}

	public void setNotificationMailToSend(boolean notificationMailToSend) {
		this.notificationMailToSend = notificationMailToSend;
	}

	public String getNotificationMailSender() {
		return notificationMailSender;
	}

	public void setNotificationMailSender(String notificationMailSender) {
		this.notificationMailSender = notificationMailSender;
	}

	public String getNotificationMailReceiver() {
		return notificationMailReceiver;
	}

	public void setNotificationMailReceiver(String notificationMailReceiver) {
		this.notificationMailReceiver = notificationMailReceiver;
	}

	/**
	 * toString
	 */
	public String toString() {
		String ret = "";
		ret += "thresholdScaleUp=" + thresholdScaleUp + "\n";
		ret += "thresholdScaleDown=" + thresholdScaleDown + "\n";
		ret += "rateProbePattern=" + rateProbePattern + "\n";
		ret += "heartbeatProbePattern=" + heartbeatProbePattern + "\n";
		ret += "clusterSize=" + clusterSize + "\n";
		ret += "notificationDomain=" + notificationDomain + "\n";
		ret += "notificationServer=" + notificationServer + "\n";
		ret += "notificationMailToSend=" + notificationMailToSend + "\n";
		ret += "notificationMailSender=" + notificationMailSender + "\n";
		ret += "notificationMailReceiver=" + notificationMailReceiver + "\n";
		return ret;


	}

}
