/**
 * JPaaS
 * Copyright 2012 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * --------------------------------------------------------------------------
 * $Id: $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.jpaas.thresholddetector.core.context;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * Context of the Threshold Detector Manager
 *
 * @author pelletib
 */
public class GlobalContext {

	/**
	 * Total request rate
	 */
	Double totalRequestRate = 0.0;

	/**
	 * Node request rate
	 */
	Double nodeRequestRate = 0.0;


	/**
     * nodes list with their state.
     */
    private Map<String, NodeContext> nodesContext =
        new HashMap<String, NodeContext>();


	/**
	 * @return number of node in the specified state
	 */
	private int getNodeCounter(NodeContext.State state) {
		int counter = 0;

		Set<String> set = nodesContext.keySet();
		for (String nodeName : set) {
			NodeContext nc = nodesContext.get(nodeName);
			if (nc.getStateAsEnum().equals(state)) {
				counter++;
			}
		}

		return counter;
	}

	/**
	 * @return number of node in the 'STARTED' state
	 */
	public int getStartedNodeCounter() {
		return getNodeCounter(NodeContext.State.STARTED);
	}

	/**
	 * @return number of node in the 'STARTING' state
	 */
	public int getStartingNodeCounter() {
		return getNodeCounter(NodeContext.State.STARTING);
	}

	/**
	 * @return number of node in the 'JOINED' state
	 */
	public int getJoinedNodeCounter() {
		return getNodeCounter(NodeContext.State.JOINED);
	}

	/**
	 * @return number of node in the 'ERROR' state
	 */
	public int getErrorNodeCounter() {
		return getNodeCounter(NodeContext.State.ERROR);
	}

	/**
	 * @return number of node in the 'FREE' state
	 */
	public int getFreeNodeCounter() {
		return getNodeCounter(NodeContext.State.FREE);
	}

	/**
	 * @return number of node in the 'NOTAVAILABLE' state
	 */
	public int getNotAvailableNodeCounter() {
		return getNodeCounter(NodeContext.State.NOTAVAILABLE);
	}

	/**
	 * @return number of node in the 'CREATED' state
	 */
	public int getCreatedNodeCounter() {
		return getNodeCounter(NodeContext.State.CREATED);
	}

	/**
	 * @return number of node in the 'CREATING' state
	 */
	public int getCreatingNodeCounter() {
		return getNodeCounter(NodeContext.State.CREATING);
	}

	/**
	 * @return number of node in the 'STOPPED' state
	 */
	public int getStoppedNodeCounter() {
		return getNodeCounter(NodeContext.State.STOPPED);
	}


	public Double getTotalRequestRate() {
		return totalRequestRate;
	}

	public void setTotalRequestRate(Double totalRequestRate) {
		this.totalRequestRate = totalRequestRate;
	}

	public Double getNodeRequestRate() {
		return nodeRequestRate;
	}

	public void setNodeRequestRate(Double nodeRequestRate) {
		this.nodeRequestRate = nodeRequestRate;
	}


	public String toString() {
		String ret = "";
		ret += "totalRequestRate=" + totalRequestRate + "\n";
		ret += "nodeRequestRate=" + nodeRequestRate + "\n";
		ret += "startedNodeNumber=" + getStartedNodeCounter() + "\n";
		ret += "joinedNodeNumber=" + getJoinedNodeCounter() + "\n";
		return ret;
	}

	/**
	 * Add node context
	 * @param name
	 * @param nodeContext
	 */
	public void addNodeContext(String name, NodeContext nodeContext) {
		nodesContext.put(name, nodeContext);

	}

	/**
	 * @return get node context from name
	 */
	public NodeContext getNodeContext(String name) {
		NodeContext node = nodesContext.get(name);
		return node;
	}

	/**
	 * @return node context list
	 */
	public List<NodeContext> getNodeContextList() {

		ArrayList<NodeContext> list = new ArrayList<NodeContext>(nodesContext.values());
		return list;
	}


}
