/**
 * JPaaS
 * Copyright 2012 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * --------------------------------------------------------------------------
 * $Id: $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.jpaas.thresholddetector.core.context;

import java.io.Serializable;


/**
 * Node runtime context
 *
 * @author pelletib
 */
public class NodeContext implements Serializable {

    /**
	 *
	 */
	private static final long serialVersionUID = 1L;

	/**
     * name
     */
    private String name;

    /**
     * state
     */
    private State state;

    public enum State {
    	NOTAVAILABLE,  // not ready
    	FREE,  // ready
    	ERROR,  // in error (operation aborted)
    	CREATING, // in creation
    	CREATED, // provisioning is ok, ready to start
    	STARTING, // starting in progress
    	STARTED, // started but not in cluster
    	STOPPED, // stopped (manually?) or on error
    	JOINED // in the cluster
    }

    /**
     * rate
     */
    private double rate;

    /**
     * Constructor
     */
    public NodeContext() {
        state = State.NOTAVAILABLE;
        rate=0.0;
    }


	public double getRate() {
		return rate;
	}

	public void setRate(double rate) {
		this.rate = rate;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public State getStateAsEnum() {
		return state;
	}

	public String getState() {
		return state.name();
	}

	public void setState(State state) {
		this.state = state;
	}

	public void setState(String state) {
		this.state = State.valueOf(state);
	}


	public String toString() {

		String ret = "\n";
		ret += "Node [" + this.getName() + "].state=" + this.getState() + "\n";
		ret += "Node [" + this.getName() + "].rate=" + this.getRate() + "\n";

		return ret;
	}

}
