/**
 * JPaaS
 * Copyright 2012 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * --------------------------------------------------------------------------
 * $Id: $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.jpaas.thresholddetector.core.drools;

import java.util.HashMap;
import java.util.List;

import org.drools.runtime.rule.FactHandle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.InvalidSyntaxException;
import org.osgi.util.tracker.ServiceTracker;
import org.ow2.jasmine.rules.api.IDroolsWorkingMemory;
import org.ow2.jasmine.rules.api.IDroolsWorkingMemoryPool;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 *
 * @author pelletib
 */
public class IDroolsWorkingMemoryPoolProxy implements IDroolsWorkingMemoryPool {

    /**
     * Logger
     */
    private static Log logger = LogFactory.getLog(IDroolsWorkingMemoryPoolProxy.class);


    private ServiceTracker tracker;

    public IDroolsWorkingMemoryPoolProxy(BundleContext bundleContext) {
        tracker = new ServiceTracker(bundleContext, IDroolsWorkingMemoryPool.class.getName(), null);
    }

    public void start() throws InvalidSyntaxException {
        tracker.open();
    }

    public void stop() {
        tracker.close();
    }

    private IDroolsWorkingMemoryPool findIDroolsWorkingMemoryPool() {
        return (IDroolsWorkingMemoryPool) tracker.getService();
    }

	public void add(String arg0, IDroolsWorkingMemory arg1) throws Exception {
		IDroolsWorkingMemoryPool wmp = findIDroolsWorkingMemoryPool();
        if (wmp != null) {
        	wmp.add(arg0, arg1);
        } // no-op

	}

	public IDroolsWorkingMemory get(String arg0) {
		IDroolsWorkingMemoryPool wmp = findIDroolsWorkingMemoryPool();
        if (wmp != null) {
        	return wmp.get(arg0);
        }
        return null;
	}

	@Override
	public IDroolsWorkingMemory getOrCreate(String arg0) throws Exception {
		IDroolsWorkingMemoryPool wmp = findIDroolsWorkingMemoryPool();
        if (wmp != null) {
        	logger.debug("service wmp={0}", wmp);
        	return wmp.getOrCreate(arg0);
        }
    	logger.warn("service unavailable -> return null");
        return null;
	}

	@Override
	public List<String> getWorkingMemoriesNames() {
		IDroolsWorkingMemoryPool wmp = findIDroolsWorkingMemoryPool();
        if (wmp != null) {
        	return wmp.getWorkingMemoriesNames();
        }
        return null;
	}

	@Override
	public HashMap<String, FactHandle> insertAll(Object arg0) {
		IDroolsWorkingMemoryPool wmp = findIDroolsWorkingMemoryPool();
        if (wmp != null) {
        	return wmp.insertAll(arg0);
        } // no-op
        return null;
	}

	@Override
	public IDroolsWorkingMemory remove(String arg0) throws Exception {
		IDroolsWorkingMemoryPool wmp = findIDroolsWorkingMemoryPool();
        if (wmp != null) {
        	return wmp.remove(arg0);
        } // no-op
        return null;
	}

	@Override
	public void startAll() throws Exception {
		IDroolsWorkingMemoryPool wmp = findIDroolsWorkingMemoryPool();
        if (wmp != null) {
        	wmp.startAll();
        } // no-op

	}

	@Override
	public void stopAll() {
		IDroolsWorkingMemoryPool wmp = findIDroolsWorkingMemoryPool();
        if (wmp != null) {
        	wmp.stopAll();
        } // no-op

	}



}
