/**
 * JPaaS
 * Copyright 2012 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * --------------------------------------------------------------------------
 * $Id: $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.jpaas.thresholddetector.core.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.InvalidSyntaxException;
import org.osgi.service.event.Event;
import org.osgi.service.event.EventAdmin;
import org.osgi.util.tracker.ServiceTracker;
import org.ow2.jonas.jpaas.thresholddetector.core.actuator.Actuator;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * A {@code EventAdminProxy} is ...
 *
 * @author Guillaume Sauthier
 */
public class EventAdminProxy implements EventAdmin {

	/**
     * Logger
     */
    private static Log logger = LogFactory.getLog(EventAdminProxy.class);


    private ServiceTracker tracker;

    public EventAdminProxy(BundleContext bundleContext) {
		logger.info("Creates  EventAdminProxy");

        tracker = new ServiceTracker(bundleContext, EventAdmin.class.getName(), null);
    }

    public void start() throws InvalidSyntaxException {
		logger.info(" EventAdminProxy start");
		tracker.open();
    }

    public void stop() {
		logger.info(" EventAdminProxy start");
        tracker.close();
    }

    private EventAdmin findEventAdmin() {
        return (EventAdmin) tracker.getService();
    }

    public void postEvent(Event event) {
        EventAdmin ea = findEventAdmin();
        if (ea != null) {
        	logger.info("postEvent:" + event);
            ea.postEvent(event);
        } else {
        	logger.info("Unable to postEvent (service unavailable)");

        }
    }

    public void sendEvent(Event event) {
        EventAdmin ea = findEventAdmin();
        if (ea != null) {
        	logger.info("sendEvent:" + event);
            ea.sendEvent(event);
        } else {
        	logger.info("Unable to postEvent (service unavailable)");

        }
    }

}
