/**
 * JPaaS
 * Copyright 2012 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * --------------------------------------------------------------------------
 * $Id: $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.jpaas.thresholddetector.core.sr;

import java.util.List;

import org.ow2.jonas.jpaas.thresholddetector.core.configuration.GlobalConfiguration;
import org.ow2.jonas.jpaas.thresholddetector.core.context.GlobalContext;
import org.ow2.jonas.jpaas.thresholddetector.core.context.NodeContext;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;


/**
 * System representation of the Threshold Detector Manager.
 *
 * @author pelletib
 */
public class SystemRepresentation implements SystemRepresentationMBean{

    /**
     * Logger
     */
    private static Log logger = LogFactory.getLog(SystemRepresentation.class);

    /**
     * Configuration of the manager.
     */
    private GlobalConfiguration globalConfiguration;

	/**
     * Global context.
     */
    private GlobalContext globalContext;

    /**
     * Creates the SR
     * @param configuration
     */
	public SystemRepresentation() {

	}

    /**
     * Init Global Context
     */
	public void initGlobalContext() {

		globalContext = new GlobalContext();
	}

    /**
     * Init Node Context
     */
	public void initNodesContext() {

	}

	/**
	 * @return number of node in the 'STARTED' state
	 */
	@Override
	public int getStartedNodeCounter() {
		return getGlobalContext().getStartedNodeCounter();
	}

	/**
	 * @return number of node in the 'STARTING' state
	 */
	@Override
	public int getStartingNodeCounter() {
		return getGlobalContext().getStartingNodeCounter();
	}

	/**
	 * @return number of node in the 'JOINED' state
	 */
	@Override
	public int getJoinedNodeCounter() {
		return getGlobalContext().getJoinedNodeCounter();
	}

	/**
	 * @return number of node in the 'ERROR' state
	 */
	@Override
	public int getErrorNodeCounter() {
		return getGlobalContext().getErrorNodeCounter();
	}

	/**
	 * @return number of node in the 'FREE' state
	 */
	@Override
	public int getFreeNodeCounter() {
		return getGlobalContext().getFreeNodeCounter();
	}

	/**
	 * @return number of node in the 'NOTAVAILABLE' state
	 */
	@Override
	public int getNotAvailableNodeCounter() {
		return getGlobalContext().getNotAvailableNodeCounter();
	}

	/**
	 * @return number of node in the 'CREATED' state
	 */
	@Override
	public int getCreatedNodeCounter() {
		return getGlobalContext().getCreatedNodeCounter();
	}

	/**
	 * @return number of node in the 'CREATING' state
	 */
	@Override
	public int getCreatingNodeCounter() {
		return getGlobalContext().getCreatingNodeCounter();
	}

	/**
	 * @return number of node in the 'STOPPED' state
	 */
	@Override
	public int getStoppedNodeCounter() {
		return getGlobalContext().getStoppedNodeCounter();
	}

	/**
	 * @return get node context from name
	 */
	public NodeContext getNodeContext(String name) {
		if (name != null) {
			return getGlobalContext().getNodeContext(name);
		} else {
			return null;
		}
	}

	/**
	 * @return number of node in the 'started' state
	 */
	public void setNodeState(String name, String state) {
		NodeContext node = getGlobalContext().getNodeContext(name);
		if (node == null) {
	        logger.warn("Node {0} unknown", name);
		} else {
			node.setState(state);
		}
	}

	/**
	 * @return state of the node
	 */
	public String getNodeState(String name) {
		NodeContext node = getGlobalContext().getNodeContext(name);
		if (node == null) {
	        logger.warn("Node {0} unknown", name);
	        return null;
		} else {
			return node.getState();
		}
	}

	/**
	 * @return node context list
	 */
	public List<NodeContext> getNodeContextList() {

		return getGlobalContext().getNodeContextList();
	}

	/**
	 *
	 * @return global configuration
	 */
    public GlobalConfiguration getGlobalConfiguration() {
		return globalConfiguration;
	}

    /**
     * set global configuration
     * @param globalConfiguration
     */
	public void setGlobalConfiguration(GlobalConfiguration globalConfiguration) {
		this.globalConfiguration = globalConfiguration;
	}

	/**
	 *
	 * @return global context
	 */
	public GlobalContext getGlobalContext() {
		return globalContext;
	}

	/**
	 *  set global context
	 * @param globalContext
	 */
	public void setGlobalContext(GlobalContext globalContext) {
		this.globalContext = globalContext;
	}

	@Override
	public Double getNodeRequestRate() {
		return getGlobalContext().getNodeRequestRate();
	}

	@Override
	public Double getTotalRequestRate() {
		return getGlobalContext().getTotalRequestRate();
	}
}
